@@ -37,9 +37,18 @@ ALIASES = {
 }
 
 def generate_project(projectName):
+    projectName = clean_project_name(projectName)
     click.echo('project generated ' + projectName)
     create_project(projectName)
 
+def generate_p(projectName):
+    projectName = clean_project_name(projectName)
+    click.echo('project generated ' + projectName)
+    create_project(projectName)
+
+def clean_project_name(projectName):
+    projectName = projectName.replace('-', '_')
+    return projectName
 def create_project(projectName):
     create_folder(projectName)
     create_pipeline_file(projectName, 'preprocessor')
@@ -56,7 +65,6 @@ def create_folder(projectName):
 def create_pipeline_file(projectName, pipelineType):
     with open(os.path.join(__location__, 'cli/' + pipelineType + '_template.py'), 'r') as file:
         data = file.read()
-        projectName = projectName.replace('-', '_')
         projectNameNoUnderscore = ''.join(elem.capitalize() for elem in projectName.split('_'))
         className = projectNameNoUnderscore + pipelineType.capitalize()
         classNameFotBaseObject = projectNameNoUnderscore + '_' + pipelineType
